@@ -1,4 +1,4 @@
-from typing import Optional
+from typing import Optional, Union
 
 from pydantic import root_validator
 
@@ -31,13 +31,13 @@ class HardwareReturnSchema(Schema):
     """
 
     name: HardwareType
-    label: Optional[HardwareTypeLabel] = None
+    label: Union[HardwareTypeLabel, HardwareType]
 
     @root_validator(pre=True)
     def add_label(cls, values):
-        hardware = values["name"].name
-        if hardware in HardwareTypeLabel.__members__:
-            values["label"] = HardwareTypeLabel[hardware]
+        hardware = values["name"]
+        name = hardware.name
+        values["label"] = HardwareTypeLabel[name] if name in HardwareTypeLabel.__members__ else hardware
         return values
 
     vendor: Optional[HardwareVendor] = None
